bayespy.nodes.SwitchingGaussianMarkovChain.lower_bound_contribution
===================================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.lower_bound_contribution